package cn.iocoder.yudao.module.inspection.service;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.IService;
import cn.iocoder.yudao.module.inspection.entity.InspectionInfo;

import java.util.List;
import java.util.Map;

/**
 * 【请填写功能名称】Service接口
 *
 * @author ruoyi
 * @date 2023-08-13
 */
public interface IInspectionInfoService  extends IService<InspectionInfo>
{
    /**
     * 查询【请填写功能名称】
     *
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    public InspectionInfo selectInspectionInfoById(Long id);

    /**
     * 查询【请填写功能名称】列表
     *
     * @param inspectionInfo 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public List<InspectionInfo> selectInspectionInfoList(InspectionInfo inspectionInfo);

    /**
     * 新增【请填写功能名称】
     *
     * @param inspectionInfo 【请填写功能名称】
     * @return 结果
     */
    public int insertInspectionInfo(InspectionInfo inspectionInfo) throws Exception;
    void settleAccounts(Long InspectionId);
    /**
     * 修改【请填写功能名称】
     *
     * @param inspectionInfo 【请填写功能名称】
     * @return 结果
     */
    public int updateInspectionInfo(InspectionInfo inspectionInfo) throws Exception;

    /**
     * 批量删除【请填写功能名称】
     *
     * @param ids 需要删除的【请填写功能名称】主键集合
     * @return 结果
     */
    public int deleteInspectionInfoByIds(Long ids);

    /**
     * 删除【请填写功能名称】信息
     *
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
    public int deleteInspectionInfoById(Long id);
    List<InspectionInfo> workOrder(Long partnerId, String carNum, String goodsTitle, String customerSource, String payType, String startTime, Long roleId, String endTime);
    List<InspectionInfo> delworkOrder(Long partnerId, String carNum, String goodsTitle,String customerSource,String payType,String startTime,Long roleId,String endTime);


    Map<String,Object> workOrderData(Long partnerId, String carNum, String goodsTitle, String customerSource, String payType, String startTime, Long roleId, String endTime);

}
